"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const CheckingHelper_1 = require("./CheckingHelper");
class DataHelper {
    static handleDataModelInput(dataInput) {
        Object.keys(dataInput).forEach(key => {
            if (dataInput[key] === undefined)
                delete dataInput[key];
            else if (dataInput[key] === null || dataInput[key] === 'null')
                dataInput[key] = undefined;
        });
    }
    static handleIdDataModel(data) {
        return data && !data._id ? data.toString() : data;
    }
    static handleFileDataModel(file) {
        if (file) {
            if (file.url)
                return file.url;
            return file.toString();
        }
        return undefined;
    }
    static applyTemplate(template, ...params) {
        return template.replace(/{(\d+)}/g, (match, number) => {
            return params[number] || match;
        });
    }
    static convertToCurrency(value, option) {
        if (typeof value !== 'number')
            return '';
        if (!option)
            option = {};
        if (!option.format)
            option.format = 'en-US';
        if (!option.currency)
            option.currency = 'USD';
        return value.toLocaleString(option.format, { style: 'currency', currency: option.currency });
    }
    static convertStringToBoolean(val) {
        if (!val)
            return false;
        val = val.toString();
        switch (val.toLowerCase().trim()) {
            case 'true':
            case 'yes':
            case '1': return true;
            case 'false':
            case 'no':
            case '0': return false;
            default: return false;
        }
    }
    static getContextUrl(val) {
        if (CheckingHelper_1.default.isNotUndefineAndNull(val)) {
            let strUrl = val.split('/');
            if (CheckingHelper_1.default.isNotUndefineAndNull(strUrl) && CheckingHelper_1.default.isArray(strUrl)) {
                let result = {
                    controller: '',
                    action: '',
                    other: ['']
                };
                let i = 0;
                strUrl.forEach(item => {
                    if (item !== '' && item !== 'api' && !CheckingHelper_1.default.isNumber(item)) {
                        if (i === 0) {
                            result.controller = item;
                        }
                        if (i === 1) {
                            result.action = item;
                        }
                        if (i > 1) {
                            result.other.push(item);
                        }
                        i++;
                    }
                });
                return result;
            }
        }
        return '';
    }
}
Object.seal(DataHelper);
exports.default = DataHelper;
//# sourceMappingURL=DataHelper.js.map