"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const CheckingHelper_1 = require("./CheckingHelper");
class RedisHelper {
    constructor(client) {
        this.client = client;
    }
    async getKey(key, convertKey = false) {
        try {
            let type = await this.client.typeAsync(key);
            if (type === 'string') {
                let detail = await this.client.getAsync(key);
                return detail;
            }
            else if (type === 'hash') {
                let detail = await this.client.hgetallAsync(key);
                if (detail && convertKey) {
                    let xRes = Object.keys(detail).map(function (a1, a2, a3) {
                        return { key: a1, value: detail[a1] };
                    });
                    return xRes;
                }
                return detail;
            }
            else if (type === 'set') {
                let detail = await this.client.smembersAsync(key);
                return detail;
            }
        }
        catch (error) {
            return error;
        }
    }
    async deleteKey(key) {
        try {
            let detail = await this.client.delAsync(key);
            return detail;
        }
        catch (error) {
            return error;
        }
    }
    async deleteHash(key, field) {
        try {
            let detail = await this.client.hdelAsync(key, field);
            return detail;
        }
        catch (error) {
            return error;
        }
    }
    async updateKey(data) {
        try {
            if (data.type === 'string') {
                let res = await this.deleteKey(data.key);
                let detail = await this.createKey(data);
                return detail;
            }
            else if (data.type === 'hash') {
                let res = await this.deleteHash(data.key, data.field ? data.field : '');
                let detail = await this.createKey(data);
                return detail;
            }
            else if (data.type === 'set') {
                let res = await this.client.sremAsync(data.key, data.value);
                let detail = await this.createKey(data);
                return detail;
            }
        }
        catch (error) {
            return error;
        }
    }
    async createKey(data) {
        try {
            if (data.type === 'string') {
                if (data.expired && data.expired > 0) {
                    let detail = await this.client.setAsync(data.key, data.value, 'EX', data.expired);
                    return detail;
                }
                else {
                    let detail = await this.client.setAsync(data.key, data.value);
                    return detail;
                }
            }
            else if (data.type === 'hash') {
                let detail = await this.client.hsetAsync(data.key, data.field, data.value);
                return detail;
            }
            else if (data.type === 'hash-hmset' && data.data) {
                Object.keys(data.data).map((value, index) => {
                    let xval = data.data[value];
                    if (CheckingHelper_1.default.isObject(xval)) {
                        xval = JSON.stringify(xval);
                        data.data[value] = xval;
                    }
                });
                let detail = await this.client.hmsetAsync(data.key, data.data);
                await this.client.expireAsync(data.key, data.expired);
                return detail;
            }
            else if (data.type === 'set') {
                let detail = await this.client.saddAsync(data.key, data.value);
                return detail;
            }
        }
        catch (error) {
            return error;
        }
    }
    async renameKey(oldKey, newKey) {
        let detail = await this.client.renamenxAsync(oldKey, newKey);
        return detail;
    }
    async setExpired(key, timeout) {
        let detail = await this.client.expireAsync(key, timeout);
        return detail;
    }
    async updateHash(key, field, value) {
        let detail = await this.client.hsetAsync(key, field, value);
        return detail;
    }
    async refreshToken(oldKey, newKey, timeout) {
        let detail = await this.client.renamenxAsync(oldKey, newKey);
        await this.client.expireAsync(newKey, timeout);
        return detail;
    }
}
exports.default = RedisHelper;
//# sourceMappingURL=RedisHeplper.js.map