"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const path = require("path");
const fs = require("fs");
const jsonfile = require("jsonfile");
const compression = require("compression");
class SystemHelper {
    static get getConfig() {
        if (fs.existsSync(SystemHelper.pathConfig)) {
            let config = jsonfile.readFileSync(SystemHelper.pathConfig);
            return config;
        }
        else if (fs.existsSync('./config.json')) {
            let config = jsonfile.readFileSync('./config.json');
            return config;
        }
        console.log('\x1b[31m', 'config.json not found! \r\n Please check in the root folder exist config.json', '\x1b[0m');
        return undefined;
    }
    static get Development() {
        let config = SystemHelper.getConfig;
        if (config && config.DEVELOPMENT)
            return config.DEVELOPMENT;
        else
            return new ConfigSystem();
    }
    static get Production() {
        let config = SystemHelper.getConfig;
        if (config && config.PRODUCTION)
            return config.PRODUCTION;
        else
            return new ConfigSystem();
    }
    static InjectControllers(controllerPath, excludes) {
        const directory = controllerPath;
        let files = fs
            .readdirSync(directory)
            .filter(item => ['.ts', '.js'].includes(path.extname(item)) &&
            !fs.statSync(path.join(directory, item)).isDirectory());
        if (excludes) {
            files = files.filter(x => !excludes.includes(x));
        }
        return files.map(file => {
            let fileImport = require(path.join(directory, file));
            return fileImport.default || fileImport;
        });
    }
    static shouldCompress(req, res) {
        if (req.headers['x-no-compression']) {
            return false;
        }
        return compression.filter(req, res);
    }
}
SystemHelper.pathConfig = '../config.json';
exports.default = SystemHelper;
class ConfigSystem {
    constructor() {
        this.SERVER = {
            DOMAIN: '',
            PORT: 0
        };
        this.SERVICE = {
            POSTGRES_DB: false,
            REDIS: false,
            RABBITMQ: false,
            EVENTSTORE: false
        };
        this.DATABASES = {
            DATABASE_DYAMICS: [],
            POSTGRES: {
                NAME: '',
                HOST: '',
                PORT: 0,
                DB_NAME: '',
                USERNAME: '',
                PASSWORD: '',
            },
            MONGO: {
                NAME: '',
                HOST: '',
                PORT: 0,
                DB_NAME: '',
                USERNAME: '',
                PASSWORD: '',
            }
        };
        this.RABBITMQ = {
            HOST: '',
            PORT: 0,
            USER: '',
            PWD: '',
        };
        this.REDIS = {
            HOST: '',
            PORT: 0,
            PASSWORD: '',
        };
        this.EVENT_STORE = {
            NAME: '',
            HOST: '',
            PORT: 0,
            DB_NAME: '',
            USERNAME: '',
            PASSWORD: '',
        };
        this.PATHS = {
            LOGPATH: ''
        };
        this.SMTP = {
            AUTHENTICATOR: {
                USERNAME: '',
                PASSWORD: '',
            },
            SENDER: {
                NAME: '',
                EMAIL: '',
            }
        };
    }
}
//# sourceMappingURL=SystemHelper.js.map